
#
# Patch managed by http://www.holgerschurig.de/patcher.html
#

--- cvs/roundup/cgi/templating.py~classhelp	2005-05-09 17:24:50.000000000 +0200
+++ cvs/roundup/cgi/templating.py	2005-05-11 12:37:28.000000000 +0200
@@ -620,7 +620,8 @@
         return l
 
     def classhelp(self, properties=None, label=''"(list)", width='500',
-            height='400', property='', form='itemSynopsis'):
+            height='400', property='', form='itemSynopsis',
+            pagesize=50, sort=None, filter=None):
         '''Pop up a javascript window with class help
 
         This generates a link to a popup window which displays the
@@ -630,8 +631,16 @@
         properties of a class (excluding id, creator, created and
         activity).
 
-        You may optionally override the label displayed, the width and
-        height. The popup window will be resizable and scrollable.
+        You may optionally override the label displayed, the width,
+        the height, the number of items per page and the field on which
+        the list is sorted (defaults to username if in the displayed
+        properties).
+
+        With the "filter" arg it is possible to specify a filter for
+        which items are supposed to be displayed. It has to be of
+        the format "<field>=<values>;<field>=<values>;...".
+
+        The popup window will be resizable and scrollable.
 
         If the "property" arg is given, it's passed through to the
         javascript help_window function.
@@ -644,13 +653,31 @@
             properties = self._klass.getprops(protected=0).keys()
             properties.sort()
             properties = ','.join(properties)
+        if sort is None:
+            if 'username' in properties.split( ',' ):
+                sort = '&amp;@sort=username'
+            else:
+                sort = ''
+        else:
+            sort = '&amp;@sort=' + sort
         if property:
             property = '&amp;property=%s'%property
         if form:
             form = '&amp;form=%s'%form
+        if filter:
+            filterprops = filter.split(';')
+            filtervalues = []
+            names = []
+            for x in filterprops:
+                (name, values) = x.split('=')
+                names.append(name)
+                filtervalues.append('&amp;%s=%s' % (name, urllib.quote(values)))
+            filter = '&amp;@filter=%s%s' % (','.join(names), ''.join(filtervalues))
+        else:
+           filter = ''
         help_url = "%s?@startwith=0&amp;@template=help&amp;"\
-                   "properties=%s%s%s" % \
-                   (self.classname, properties, property, form)
+                   "properties=%s%s%s%s&amp;@pagesize=%s%s" % \
+                   (self.classname, properties, property, form, sort, pagesize, filter)
         onclick = "javascript:help_window('%s', '%s', '%s');return false;" % \
                   (help_url, width, height)
         return '<a class="classhelp" href="%s" onclick="%s">%s</a>' % \
--- cvs/templates/classic/html/issue.item.html~classhelp	2005-05-09 17:24:54.000000000 +0200
+++ cvs/templates/classic/html/issue.item.html	2005-05-11 13:53:22.000000000 +0200
@@ -66,7 +66,7 @@
  <td>
   <span tal:replace="structure context/nosy/field" />
   <span tal:condition="context/is_edit_ok" tal:replace="structure
-python:db.user.classhelp('username,realname,address', property='nosy', width='600')" /><br>
+python:db.user.classhelp('username,realname,address', property='nosy', width='600', pagesize='100', sort='realname' )" /><br>
  </td>
 </tr>
 
@@ -77,7 +77,7 @@
  <th>Products</th>
  <td>
   <span tal:replace="structure context/product/field" />
-  <span tal:condition="context/is_edit_ok" tal:replace="structure python:db.product.classhelp('title,comment',property='product')" />
+  <span tal:condition="context/is_edit_ok" tal:replace="structure python:db.product.classhelp('title,comment',property='product',sort='title',filter='status='+notresolved)" />
  </td>
  </tal:block>
 </tr>

 	  	 
